@@ -9,11 +9,11 @@ applications interacting with requests
 .. module_author:: Niel (Ketov) Gorev <ketov-x@ya.ru>
 .. module_author:: http://t.me/ketov-x
 """
-from dataclasses import dataclass, field
+from typing import Optional, List
+
 from scintillant.apimodels.types import DialogAnswerRequestType
 
 
-@dataclass()
 class DialogAnswerRequest(DialogAnswerRequestType):
     """Request model for the Dialog service.
 
@@ -52,11 +52,11 @@ class DialogAnswerRequest(DialogAnswerRequestType):
     >> choices = ClientResponse(...).choices # [["Choose the first", 1], ["Choose the second", 2]]
     >> da = DialogAnswerRequest(..., in_choice="Choose the first")``
     """
-    client_id: str = field()
-    client_app: str = field()
-    in_text: str = field(default=None)
-    in_choice: str = field(default=None)
-    client_type: str = field(default='text')
+    client_id: str
+    client_app: str
+    in_text: str = None
+    in_choice: str = None
+    client_type: str = 'text'
 
     @classmethod
     def from_dict(cls, data: dict) -> DialogAnswerRequestType:
@@ -73,13 +73,7 @@ class DialogAnswerRequest(DialogAnswerRequestType):
         :param data: Model Generation Data.
         :return: DialogAnswerRequest
         """
-        return cls(
-            client_id=data.get('client_id'),
-            client_app=data.get('client_app'),
-            client_type=data.get('client_type'),
-            in_text=data.get('in_text'),
-            in_choice=data.get('in_choice'),
-        )
+        return cls(**data)
 
     def serialize_json(self) -> dict:
         """Returns a templated dictionary based on the fields of the class.
@@ -102,10 +96,4 @@ class DialogAnswerRequest(DialogAnswerRequestType):
 
         :return: dict
         """
-        return {
-            'client_id': self.client_id,
-            'client_app': self.client_app,
-            'client_type': self.client_type,
-            'in_text': self.in_text,
-            'in_choice': self.in_choice
-        }
\ No newline at end of file
+        return self.dict()
\ No newline at end of file
