@@ -1,3 +1,4 @@
+from abc import abstractmethod, ABC
 from typing import Callable, Type
 from pydantic import BaseModel
 
@@ -8,13 +9,21 @@ from scintillant.outs import Dictionary
 from loguru import logger
 
 
+class Vault(BaseModel, metaclass=ABC):
+
+    @abstractmethod
+    @classmethod
+    def create(cls, data: SkillRequestType):
+        pass
+
+
 class ContextUpdater:
     states = {}  # state_name: state_func
     exit_phrases = ['exit', 'выход', 'хватит', 'остановись']
 
     def __init__(self, data: SkillRequestType,
                  dictionary: Type[Dictionary] = None,
-                 vault = None):
+                 vault: Type[Vault] = None):
         # Default parameters for find state and complete it
         self.data = data
         self.context = data.context
@@ -28,7 +37,7 @@ class ContextUpdater:
         if vault and '__vault__' in self.context:
             self.vault = vault(**self.context['__vault__'])
         elif vault:
-            self.vault = vault
+            self.vault = vault.create(data)
             self.context['__vault__'] = self.vault.dict()
 
     @property
